juju package
============

Subpackages
-----------

.. toctree::

    juju.client

Submodules
----------

juju.action module
------------------

.. automodule:: juju.action
    :members:
    :undoc-members:
    :show-inheritance:

juju.annotation module
----------------------

.. automodule:: juju.annotation
    :members:
    :undoc-members:
    :show-inheritance:

juju.application module
-----------------------

.. automodule:: juju.application
    :members:
    :undoc-members:
    :show-inheritance:

juju.cloud module
-----------------

.. automodule:: juju.cloud
    :members:
    :undoc-members:
    :show-inheritance:

juju.constraints module
-----------------------

.. automodule:: juju.constraints
    :members:
    :undoc-members:
    :show-inheritance:

juju.controller module
----------------------

.. automodule:: juju.controller
    :members:
    :undoc-members:
    :show-inheritance:

juju.delta module
-----------------

.. automodule:: juju.delta
    :members:
    :undoc-members:
    :show-inheritance:

juju.errors module
------------------

.. automodule:: juju.errors
    :members:
    :undoc-members:
    :show-inheritance:

juju.exceptions module
----------------------

.. automodule:: juju.exceptions
    :members:
    :undoc-members:
    :show-inheritance:

juju.juju module
----------------

.. automodule:: juju.juju
    :members:
    :undoc-members:
    :show-inheritance:

juju.machine module
-------------------

.. automodule:: juju.machine
    :members:
    :undoc-members:
    :show-inheritance:

juju.model module
-----------------

.. automodule:: juju.model
    :members:
    :undoc-members:
    :show-inheritance:

juju.placement module
---------------------

.. automodule:: juju.placement
    :members:
    :undoc-members:
    :show-inheritance:

juju.relation module
--------------------

.. automodule:: juju.relation
    :members:
    :undoc-members:
    :show-inheritance:

juju.tag module
---------------

.. automodule:: juju.tag
    :members:
    :undoc-members:
    :show-inheritance:

juju.unit module
----------------

.. automodule:: juju.unit
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: juju
    :members:
    :undoc-members:
    :show-inheritance:
